Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(251)

Unified Diff: third_party/WebKit/Source/core/frame/LocalFrame.cpp

Issue 2711763007: Replace FrameLoaderClient.h with LocalFrameClient.h and rename as needed. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/frame/LocalFrame.cpp
diff --git a/third_party/WebKit/Source/core/frame/LocalFrame.cpp b/third_party/WebKit/Source/core/frame/LocalFrame.cpp
index 6d5853967979d907d2af3e104cb201bd7ab28150..49eaee03d57357a7d518acb0e5307327458146dd 100644
--- a/third_party/WebKit/Source/core/frame/LocalFrame.cpp
+++ b/third_party/WebKit/Source/core/frame/LocalFrame.cpp
@@ -50,6 +50,7 @@
#include "core/frame/FrameHost.h"
#include "core/frame/FrameView.h"
#include "core/frame/LocalDOMWindow.h"
+#include "core/frame/LocalFrameClient.h"
#include "core/frame/PerformanceMonitor.h"
#include "core/frame/Settings.h"
#include "core/frame/VisualViewport.h"
@@ -64,7 +65,6 @@
#include "core/layout/api/LayoutViewItem.h"
#include "core/layout/compositing/PaintLayerCompositor.h"
#include "core/loader/FrameLoadRequest.h"
-#include "core/loader/FrameLoaderClient.h"
#include "core/loader/NavigationScheduler.h"
#include "core/page/ChromeClient.h"
#include "core/page/FocusController.h"
@@ -260,7 +260,7 @@ inline float parentTextZoomFactor(LocalFrame* frame) {
template class CORE_TEMPLATE_EXPORT Supplement<LocalFrame>;
-LocalFrame* LocalFrame::create(FrameLoaderClient* client,
+LocalFrame* LocalFrame::create(LocalFrameClient* client,
FrameHost* host,
FrameOwner* owner,
InterfaceProvider* interfaceProvider,
@@ -438,7 +438,7 @@ void LocalFrame::detach(FrameDetachType type) {
client()->willBeDetached();
// Notify ScriptController that the frame is closing, since its cleanup ends
// up calling back to FrameLoaderClient via WindowProxy.
script().clearForClose();
setView(nullptr);
@@ -848,7 +848,7 @@ bool LocalFrame::shouldThrottleRendering() const {
return view() && view()->shouldThrottleRendering();
}
-inline LocalFrame::LocalFrame(FrameLoaderClient* client,
+inline LocalFrame::LocalFrame(LocalFrameClient* client,
FrameHost* host,
FrameOwner* owner,
InterfaceProvider* interfaceProvider,
@@ -891,8 +891,8 @@ void LocalFrame::scheduleVisualUpdateUnlessThrottled() {
page()->animator().scheduleVisualUpdate(this);
}
-FrameLoaderClient* LocalFrame::client() const {
- return static_cast<FrameLoaderClient*>(Frame::client());
+LocalFrameClient* LocalFrame::client() const {
+ return static_cast<LocalFrameClient*>(Frame::client());
}
PluginData* LocalFrame::pluginData() const {
« no previous file with comments | « third_party/WebKit/Source/core/frame/LocalDOMWindow.cpp ('k') | third_party/WebKit/Source/core/frame/VisualViewport.cpp » ('j') | no next file with comments »
@@ -438,7 +438,7 @@ void LocalFrame::detach(FrameDetachType type) {
client()->willBeDetached();
// Notify ScriptController that the frame is closing, since its cleanup ends
- // up calling back to FrameLoaderClient via WindowProxy.
+ // up calling back to LocalFrameClient via WindowProxy.
script().clearForClose();
setView(nullptr);

Powered by Google App Engine
This is Rietveld 408576698